ffmpeg_kit_extended_flutter library

Flutter plugin for FFmpeg, FFprobe, and FFplay commands on Windows, Linux, and Android. Uses Dart FFI to interact directly with native FFmpeg libraries for high performance.

Classes

ChapterInformation
Represents a chapter within a media file.
FFmpegKit
A convenience class for executing FFmpeg commands.
FFmpegKitConfig
A convenience class for global FFmpegKit configuration.
FFmpegKitExtended
The main entry point for the FFmpegKit Extended plugin.
FFmpegSession
A session for executing FFmpeg commands.
FFplayAndroidSurface
Flutter Texture-backed Android surface for FFplay video output.
FFplayDesktopTexture
Flutter Texture-backed desktop surface for FFplay video output.
FFplayKit
A utility class for managing global FFplay playback.
FFplayKitAndroid
Android-specific FFplay utilities.
FFplaySession
Session for playing media using FFplay.
FFplaySurface
Platform-unified FFplay video output surface.
FFplayView
A widget that renders an FFplaySurface at the correct aspect ratio.
FFplayViewController
Controls the fullscreen state of an FFplayView.
FFprobeKit
A convenience class for executing FFprobe commands.
FFprobeSession
A session for executing FFprobe commands.
Log
Represents a single log entry emitted by FFmpeg.
MediaInformation
Represents metadata retrieved from a media file or stream.
MediaInformationSession
A specialised FFprobeSession for retrieving detailed media information.
Session
Base class for all FFmpegKit sessions.
SessionQueueManager
Manages session execution to limit concurrent system resource usage.
Statistics
Represents encoding/decoding statistics for an active FFmpegSession.
StreamInformation
Represents a media stream within a container format.

Enums

LogLevel
FFmpeg log levels used for filtering or identifying log message severity.
LogRedirectionStrategy
Defines how log messages should be redirected to the console.
ReturnCode
Well-known exit codes returned by the native layer.
SessionState
Lifecycle state of an FFmpegKit session
Signal
Signals that can be sent to FFmpeg sessions.

Typedefs

FFmpegLogCallback = void Function(Log log)
Callback for processing log messages.
FFmpegSessionCompleteCallback = void Function(FFmpegSession session)
Callback for FFmpegSession completion.
FFmpegStatisticsCallback = void Function(Statistics statistics)
Callback for session Statistics updates.
FFplaySessionCompleteCallback = void Function(FFplaySession session)
Callback for FFplaySession completion.
FFprobeSessionCompleteCallback = void Function(FFprobeSession session)
Callback for FFprobeSession completion.

Exceptions / Errors

SessionCancelledException
Exception thrown when a session is cancelled.