SessionQueueManager class
Manages session execution to limit concurrent system resource usage.
While FFmpegKit support parallel execution, running too many sessions simultaneously can over-allocate CPU and memory. This manager ensures that sessions are executed in parallel up to a specified limit.
Constructors
- SessionQueueManager()
-
factory
Properties
- activeSessionCount → int
-
Gets the number of sessions currently executing.
no setter
-
activeSessions
→ List<
Session> -
Gets the currently executing sessions.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBusy → bool
-
Returns true if any session is currently executing.
no setter
- maxConcurrentSessions ↔ int
-
Gets the maximum number of concurrent sessions.
getter/setter pair
- queueLength → int
-
Gets the number of queued sessions waiting to execute.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelAll(
) → void - Cancels all sessions (current and queued).
-
cancelCurrent(
) → void - Cancels all currently executing sessions.
-
clearQueue(
) → void - Clears all queued sessions without executing them.
-
executeSession(
Session session, Future< void> executor()) → Future<void> - Executes a session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForAll(
) → Future< void> - Waits for all sessions (current and queued) to complete.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited